@@ -1,16 +1,15 @@
-from __future__ import unicode_literals
-
 import pytest
+
 from prompt_toolkit.buffer import Buffer
 from prompt_toolkit.history import InMemoryHistory
 
 
 @pytest.fixture
 def _history():
-    " Prefilled history. "
+    "Prefilled history."
     history = InMemoryHistory()
-    history.append_string('alpha beta gamma delta')
-    history.append_string('one two three four')
+    history.append_string("alpha beta gamma delta")
+    history.append_string("one two three four")
     return history
 
 
@@ -20,13 +19,13 @@ def _history():
 def test_empty_history():
     buf = Buffer()
     buf.yank_last_arg()
-    assert buf.document.current_line == ''
+    assert buf.document.current_line == ""
 
 
 def test_simple_search(_history):
     buff = Buffer(history=_history)
     buff.yank_last_arg()
-    assert buff.document.current_line == 'four'
+    assert buff.document.current_line == "four"
 
 
 def test_simple_search_with_quotes(_history):
@@ -39,20 +38,20 @@ def test_simple_search_with_quotes(_history):
 def test_simple_search_with_arg(_history):
     buff = Buffer(history=_history)
     buff.yank_last_arg(n=2)
-    assert buff.document.current_line == 'three'
+    assert buff.document.current_line == "three"
 
 
 def test_simple_search_with_arg_out_of_bounds(_history):
     buff = Buffer(history=_history)
     buff.yank_last_arg(n=8)
-    assert buff.document.current_line == ''
+    assert buff.document.current_line == ""
 
 
 def test_repeated_search(_history):
     buff = Buffer(history=_history)
     buff.yank_last_arg()
     buff.yank_last_arg()
-    assert buff.document.current_line == 'delta'
+    assert buff.document.current_line == "delta"
 
 
 def test_repeated_search_with_wraparound(_history):
@@ -60,7 +59,7 @@ def test_repeated_search_with_wraparound(_history):
     buff.yank_last_arg()
     buff.yank_last_arg()
     buff.yank_last_arg()
-    assert buff.document.current_line == 'four'
+    assert buff.document.current_line == "four"
 
 
 # Test yank_last_arg.
@@ -69,17 +68,17 @@ def test_repeated_search_with_wraparound(_history):
 def test_yank_nth_arg(_history):
     buff = Buffer(history=_history)
     buff.yank_nth_arg()
-    assert buff.document.current_line == 'two'
+    assert buff.document.current_line == "two"
 
 
 def test_repeated_yank_nth_arg(_history):
     buff = Buffer(history=_history)
     buff.yank_nth_arg()
     buff.yank_nth_arg()
-    assert buff.document.current_line == 'beta'
+    assert buff.document.current_line == "beta"
 
 
 def test_yank_nth_arg_with_arg(_history):
     buff = Buffer(history=_history)
     buff.yank_nth_arg(n=2)
-    assert buff.document.current_line == 'three'
+    assert buff.document.current_line == "three"
